==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Informaçoes PolicyKit</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Falha de autenticação</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>A autenticação falhou por alguma razão</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Erro PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Requer autenticação</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identidade:</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Informações PolicyKit</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Já está em curso uma autorização. Por favor tente mais tarde.</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Falha de autenticação</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>A autenticação falhou por alguma razão</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Erro PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Requer autenticação</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identidade:</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Palavra-passe:</translation>
    </message>
</context>
</TS>
